pheno.flm.fit(D,limit=1000)slm.fit() function
form the SparseM package, adapted for the estimation of combined phenological time series.
In phenological application, x should be the julian day
of observation of a certain phase, factor f1 should be the observation year
and factor f2 should be a station-id.
For large problems length(x)>limit, the linear model is calculated
for treatment contrasts for efficiency reasons, and the constraint that the sum of f2 is zero,
is adjusted afterwards. This results in a slight over-estimation of
standard errors.
Note that the input data is sorted before fitting, such that subsequent
analyses using the input data should be done using the sorted output data frame.lmdata(DWD)
R <- pheno.flm.fit(DWD) # parameter estimationRun the code above in your browser using DataLab